.. _geos:

Geographies
===========

A geography (or place) is identified uniquely by a level and a code which, when combined, form its geoid. Each level describes a different way of breaking up a country and can be units such as country, province, municipality, state or county. The code is some ID that is unique for that level, either a number or a string.

Some example geoids are:

* ``province-WC``: the Western Cape province in South Africa
* ``country-KE``: Kenya
* ``ward-19100057``: ward 19100057 in Cape Town, South Africa
* ``county-1``: the Mombasa county in Kenya

TODO:

* database tables and models
* what geographies need
* levels and names
* boundary information
